from sports.nba.nba_team import NBA_Team


class IndianaPacers(NBA_Team):
    """
    NBA Atlanta Hawks Static Information

    """
    full_name = "Indiana Pacers"
    name = "Pacers"
    team_id = 1610612754
    def __init__(self):
        """
        """
        super().__init__()



from datetime import date


class NBA_Season_2003(object):
    def __init__(self):
        self.description    = "2003–04 NBA season"
        self.start_date     = date(year=2003,month=10, day=28)
        self.end_date       = date(year=2004, month=4, day=14)

        self.playoff_start_date = date(year=2004, month=4, day=17)
        self.playoff_end_date   = date(year=2004, month=7, day=1)


from sports.nba.nba_team import NBA_Team


class SacramentoKings(NBA_Team):
    """
    NBA's Sacramento Kings Static Information

    """
    full_name = "Sacramento Kings"
    name = "Kings"
    team_id = 1610612758

    def __init__(self):
        """
        """
        super().__init__()



from enum import Enum


class Conference(Enum):
    ALL = ''
    EAST = 'East'
    WEST = 'West'


class Division(Enum):
    ALL = ''
    ATLANTIC = 'Atlantic'
    CENTRAL = 'Central'
    NORTHWEST = 'Northwest'
    PACIFIC = 'Pacific'
    SOUTHEAST = 'Southeast'
    SOUTHWEST = 'Southwest'


class Direction(Enum):
    DESC = 'DESC'
    ASC = 'ASC'


class GameSegment(Enum):
    FULL_GAME = ''
    FIRST_HALF = 'First Half'
    SECOND_HALF = 'Second Half'
    OVERTIME = 'Overtime'


class League(Enum):
    NBA = '00'
    ABA = '01'


class Location(Enum):
    ALL = ''
    HOME = 'Home'
    AWAY = 'Away'


class Outcome(Enum):
    ALL = ''
    WIN = 'W'
    LOSS = 'L'


class PlayerOrTeam(Enum):
    PLAYER = 'P'
    TEAM = 'T'


class SeasonSegment(Enum):
    FULL_SEASON = ''
    PRE_ALL_STAR = 'Pre All-Star'
    POST_ALL_STAR = 'Post All-Star'


class MeasureType(Enum):
    BASE = 'Base'
    ADVANCED = 'Advanced'
    MISC = 'Misc'
    FOUR_FACTORS = 'Four Factors'
    SCORING = 'Scoring'
    OPPONENT = 'Opponent'
    USAGE = 'Usage'


class Period(Enum):
    ALL_PERIODS = '0'
    FIRST_QUARTER = '1'
    SECOND_QUARTER = '2'
    THIRD_QUARTER = '3'
    FOURTH_QUARTER = '4'
    OVERTIME_1 = '5'
    OVERTIME_2 = '6'
    OVERTIME_3 = '7'
    OVERTIME_4 = '8'


class PerMode(Enum):
    TOTALS = "Totals"
    MINUTES = 'MinutesPer'
    MINUTE = 'PerMinute'
    GAME = "PerGame"
    PER_48 = "Per48"
    PER_40 = 'Per40'
    PER_36 = "Per36"
    PER_POSSESSION = 'PerPossession'
    PER_PLAY = 'PerPlay'
    Per100Possessions = 'Per100Possessions'
    PER_100_PLAYS = 'Per100Plays'


class SeasonType(Enum):
    ALL_STAR = "All-Star"
    REGULAR_SEASON = "Regular Season"
    PRE_SEASON = "Pre Season"
    PLAYOFFS = "Playoffs"


class StatCategory(Enum):
    POINTS = 'PTS'
    FIELD_GOALS_MADE = 'FGM'
    FIELD_GOALS_ATTEMPTS = 'FGA'
    FIELD_GOAL_PCT = 'FG%'
    FIELD_GOAL3M = '3PM'
    FIELD_GOAL3A = '3PA'
    FIELD_GOAL3_PCT = '3P%'
    FREE_THROW_MADE = 'FTM'
    FREE_THROW_ATTEMPTS = 'FTA'
    FREE_THROW_PCT = 'FT%'
    OFFENSIVE_REBOUND = 'OREB'
    DEFENSIVE_REBOUND = 'DREB'
    REBOUNDS = 'REB'
    ASSISTS = 'AST'
    STEALS = 'STL'
    BLOCKS = 'BLK'
    TURNOVER = 'TOV'
    EFF = 'EFF'
    ASSIST_TURNOVER_RATIO = 'AST/TO'
    STEAL_TURNOVER_RATIO = 'STL/TOV'



from datetime import date


class NBA_Season_2005(object):
    def __init__(self):
        self.description    = "2005–06 NBA season"
        self.start_date     = date(year=2005, month=10, day=31)
        self.end_date       = date(year=2006, month=4, day=18)

        self.playoff_start_date = date(year=2006, month=4, day=21)
        self.playoff_end_date   = date(year=2006, month=6, day=15)


from datetime import date


class NBA_Season_2002(object):
    def __init__(self):
        self.description    = "2002–03 NBA season"
        self.start_date     = date(year=2002,month=10, day=29)
        self.end_date       = date(year=2003, month=4, day=16)

        self.playoff_start_date = date(year=2003, month=4, day=19)
        self.playoff_end_date   = date(year=2003, month=5, day=29)

        self.final_start_date   = None
        self.final_end_date     = None


from sports.nba.nba_team import NBA_Team


class PhoenixSuns(NBA_Team):
    """
    NBA Golden State Warriors Static Information

    """
    full_name = "Phoenix Suns"
    name = "Suns"
    team_id = 1610612756

    def __init__(self):
        """
        """
        super().__init__()
